==> nextcloud-20.0.8p0.tgz: nextcloud/apps/accessibility/l10n/vi.js <==
OC.L10N.register(
    "accessibility",
    {
    "Dark theme" : "Chế độ ban đêm",
    "Enable dark theme" : "Bật chế độ ban đêm",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Chế độ ban đêm giúp giảm mỏi mắt bằng cách giảm tương phản ở các màu chói và giảm độ sáng. Chế độ này đang được phát triển, vì vậy, xin hãy báo cáo nếu bạn gặp bất kỳ vấn đề nào trong lúc sử dụng.",
    "High contrast mode" : "Chế độ tương phản cao",
    "Enable high contrast mode" : "Bật chế độ tương phản cao",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Chế độ tương phản cao giúp bạn dễ dàng điều hướng và phân biệt vị trí các mục chính xác hơn. Chất lượng hình ảnh sẽ giảm nhưng độ rõ sẽ được tăng lên.",
    "Dyslexia font" : "Chứng khó đọc",
    "Enable dyslexia font" : "Bật chế độ dành cho người gặp chứng khó đọc",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic là một kiểu chữ / phông chữ miễn phí được thiết kế để giảm thiểu một số lỗi đọc phổ biến do chứng khó đọc gây ra.",
    "Accessibility" : "Khả năng tiếp cận",
    "Accessibility options for nextcloud" : "Tùy chọn truy cập cho nextcloud",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Cung cấp nhiều tùy chọn truy cập để dễ dàng sử dụng Nextcloud",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Truy cập đa dạng là rất quan trọng với chúng tôi. Chúng tôi tuân theo các tiêu chuẩn mạng và kiểm tra để khiến mọi thứ đều có thể sử dụng được ngay cả khi không có chuột, và hỗ trợ những phần mềm hỗ trợ như đọc màn hình. Chúng tôi hướng đến sự tương thích với {guidelines}Nguyên Tắc Truy Cập Cho Nội Dung Mạng{linkend} 2.1  ở cấp độ AA, với chế độ tương phản cao là AAA",
    "If you find any issues, don’t hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Nếu bạn tìm được bất cứ vấn đề gì, đừng ngần ngại để báo cáo chúng trên {issuetracker} hệ thống theo dõi vấn đề của chúng tôi{linkend}. Và nếu bạn muốn can thiệp, hãy gia nhập {designteam}đội ngũ thiết kế{linkend}!"
},
"nplurals=1; plural=0;");

==> nextcloud-21.0.5.tgz: nextcloud/apps/accessibility/l10n/vi.js <==
OC.L10N.register(
    "accessibility",
    {
    "Dark theme" : "Chế độ ban đêm",
    "Enable dark theme" : "Bật chế độ ban đêm",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Chế độ ban đêm giúp giảm mỏi mắt bằng cách giảm tương phản ở các màu chói và giảm độ sáng. Chế độ này đang được phát triển, vì vậy, xin hãy báo cáo nếu bạn gặp bất kỳ vấn đề nào trong lúc sử dụng.",
    "High contrast mode" : "Chế độ tương phản cao",
    "Enable high contrast mode" : "Bật chế độ tương phản cao",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Chế độ tương phản cao giúp bạn dễ dàng điều hướng và phân biệt vị trí các mục chính xác hơn. Chất lượng hình ảnh sẽ giảm nhưng độ rõ sẽ được tăng lên.",
    "Dyslexia font" : "Chứng khó đọc",
    "Enable dyslexia font" : "Bật chế độ dành cho người gặp chứng khó đọc",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic là một kiểu chữ / phông chữ miễn phí được thiết kế để giảm thiểu một số lỗi đọc phổ biến do chứng khó đọc gây ra.",
    "Accessibility" : "Khả năng tiếp cận",
    "Accessibility options for nextcloud" : "Tùy chọn truy cập cho nextcloud",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Cung cấp nhiều tùy chọn truy cập để dễ dàng sử dụng Nextcloud",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Truy cập đa dạng là rất quan trọng với chúng tôi. Chúng tôi tuân theo các tiêu chuẩn mạng và kiểm tra để khiến mọi thứ đều có thể sử dụng được ngay cả khi không có chuột, và hỗ trợ những phần mềm hỗ trợ như đọc màn hình. Chúng tôi hướng đến sự tương thích với Nguyên Tắc Truy Cập Cho Nội Dung Mạng 2.1  ở cấp độ AA, với chế độ tương phản cao là AAA",
    "If you find any issues, don’t hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Nếu bạn tìm được bất cứ vấn đề gì, đừng ngần ngại để báo cáo chúng trên hệ thống theo dõi vấn đề của chúng tôi."
},
"nplurals=1; plural=0;");
